aboutsummaryrefslogtreecommitdiff
path: root/src/main.h
diff options
context:
space:
mode:
authorshshshsh <shshshsh@sdsdsdfsd.invalid>2014-05-30 12:35:23 +0000
committershshshsh <shshshsh@sdsdsdfsd.invalid>2014-06-04 11:58:18 +0000
commit7b45d943b29a443f1ac808c9ee4eeed6df0db9cc (patch)
tree6cb3f2990c441968386becdf4d9eab73ff876862 /src/main.h
parent97ab93f50b6f35bc362990e9dd665b90ca4132df (diff)
downloadbitcoin-7b45d943b29a443f1ac808c9ee4eeed6df0db9cc.tar.xz
Make max number of orphan blocks kept in memory a startup parameter (fixes #4253)
Diffstat (limited to 'src/main.h')
-rw-r--r--src/main.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/main.h b/src/main.h
index 8a05eb60d2..26f66630ae 100644
--- a/src/main.h
+++ b/src/main.h
@@ -45,8 +45,8 @@ static const unsigned int MAX_STANDARD_TX_SIZE = 100000;
static const unsigned int MAX_BLOCK_SIGOPS = MAX_BLOCK_SIZE/50;
/** The maximum number of orphan transactions kept in memory */
static const unsigned int MAX_ORPHAN_TRANSACTIONS = MAX_BLOCK_SIZE/100;
-/** The maximum number of orphan blocks kept in memory */
-static const unsigned int MAX_ORPHAN_BLOCKS = 750;
+/** Default for -maxorphanblocks, maximum number of orphan blocks kept in memory */
+static const unsigned int DEFAULT_MAX_ORPHAN_BLOCKS = 750;
/** The maximum size of a blk?????.dat file (since 0.8) */
static const unsigned int MAX_BLOCKFILE_SIZE = 0x8000000; // 128 MiB
/** The pre-allocation chunk size for blk?????.dat files (since 0.8) */